@@ -1,10 +1,10 @@
 from typing import List
 import pandas as pd
 
-from ..desiredState import DesiredState
-from ..decisions import Decisions
-from ..reduction import Reduction
-from ..actionRules import ActionRules
+from desiredState import DesiredState
+from decisions import Decisions
+from reduction import Reduction
+from actionRules import ActionRules
 
 
 class ActionRulesDiscovery:
